# pyqt modules
from PyQt4.QtGui import (QMainWindow)
from PyQt4.QtCore import (Qt)

# third-party modules
import config as c

# program modules 
from ui.ui_meals_window import Ui_MealsWindow

class MealsWindow(QMainWindow, Ui_MealsWindow):

    def __init__(self, parent=None, database=None):
        super(MealsWindow, self).__init__(parent)
        self.setAttribute(Qt.WA_Maemo5StackedWindow)

        self.setupUi(self)
        self.config = c.Config()
